pub fn horspool_all(pattern: &[u8], text: &[u8]) -> Vec<usize>Expand description
A simple algorithm for matching a single pattern on a text returning all occurrences.
Takes a pattern, and text text.
If the given text contains the given pattern, the algorithm returns the indexes of the first letters of all found occurrences. If the pattern could not be found in the text, an empty vector is returned.